'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_ARM_shader_core_properties'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_ARM_shader_core_properties',error_checker=_errors._error_checker)
GL_SHADER_CORE_ACTIVE_COUNT_ARM=_C('GL_SHADER_CORE_ACTIVE_COUNT_ARM',0x96F1)
GL_SHADER_CORE_COUNT_ARM=_C('GL_SHADER_CORE_COUNT_ARM',0x96F0)
GL_SHADER_CORE_FMA_RATE_ARM=_C('GL_SHADER_CORE_FMA_RATE_ARM',0x96F6)
GL_SHADER_CORE_MAX_WARP_COUNT_ARM=_C('GL_SHADER_CORE_MAX_WARP_COUNT_ARM',0x96F3)
GL_SHADER_CORE_PIXEL_RATE_ARM=_C('GL_SHADER_CORE_PIXEL_RATE_ARM',0x96F4)
GL_SHADER_CORE_PRESENT_MASK_ARM=_C('GL_SHADER_CORE_PRESENT_MASK_ARM',0x96F2)
GL_SHADER_CORE_TEXEL_RATE_ARM=_C('GL_SHADER_CORE_TEXEL_RATE_ARM',0x96F5)
@_f
@_p.types(None,_cs.GLuint)
def glMaxActiveShaderCoresARM(count):pass
