'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_fragment_shading_rate'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_fragment_shading_rate',error_checker=_errors._error_checker)
GL_FRAGMENT_SHADING_RATE_ATTACHMENT_WITH_DEFAULT_FRAMEBUFFER_SUPPORTED_EXT=_C('GL_FRAGMENT_SHADING_RATE_ATTACHMENT_WITH_DEFAULT_FRAMEBUFFER_SUPPORTED_EXT',0x96DF)
GL_FRAGMENT_SHADING_RATE_COMBINER_OP_KEEP_EXT=_C('GL_FRAGMENT_SHADING_RATE_COMBINER_OP_KEEP_EXT',0x96D2)
GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MAX_EXT=_C('GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MAX_EXT',0x96D5)
GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MIN_EXT=_C('GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MIN_EXT',0x96D4)
GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MUL_EXT=_C('GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MUL_EXT',0x96D6)
GL_FRAGMENT_SHADING_RATE_COMBINER_OP_REPLACE_EXT=_C('GL_FRAGMENT_SHADING_RATE_COMBINER_OP_REPLACE_EXT',0x96D3)
GL_FRAGMENT_SHADING_RATE_NON_TRIVIAL_COMBINERS_SUPPORTED_EXT=_C('GL_FRAGMENT_SHADING_RATE_NON_TRIVIAL_COMBINERS_SUPPORTED_EXT',0x8F6F)
GL_FRAGMENT_SHADING_RATE_WITH_SAMPLE_MASK_SUPPORTED_EXT=_C('GL_FRAGMENT_SHADING_RATE_WITH_SAMPLE_MASK_SUPPORTED_EXT',0x96DE)
GL_FRAGMENT_SHADING_RATE_WITH_SHADER_DEPTH_STENCIL_WRITES_SUPPORTED_EXT=_C('GL_FRAGMENT_SHADING_RATE_WITH_SHADER_DEPTH_STENCIL_WRITES_SUPPORTED_EXT',0x96DD)
GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_LAYERS_EXT=_C('GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_LAYERS_EXT',0x96DC)
GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_ASPECT_RATIO_EXT=_C('GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_ASPECT_RATIO_EXT',0x96DB)
GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT=_C('GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT',0x96DA)
GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT=_C('GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT',0x96D8)
GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT=_C('GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT',0x96D9)
GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT=_C('GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT',0x96D7)
GL_SHADING_RATE_1X1_PIXELS_EXT=_C('GL_SHADING_RATE_1X1_PIXELS_EXT',0x96A6)
GL_SHADING_RATE_1X2_PIXELS_EXT=_C('GL_SHADING_RATE_1X2_PIXELS_EXT',0x96A7)
GL_SHADING_RATE_1X4_PIXELS_EXT=_C('GL_SHADING_RATE_1X4_PIXELS_EXT',0x96AA)
GL_SHADING_RATE_2X1_PIXELS_EXT=_C('GL_SHADING_RATE_2X1_PIXELS_EXT',0x96A8)
GL_SHADING_RATE_2X2_PIXELS_EXT=_C('GL_SHADING_RATE_2X2_PIXELS_EXT',0x96A9)
GL_SHADING_RATE_2X4_PIXELS_EXT=_C('GL_SHADING_RATE_2X4_PIXELS_EXT',0x96AD)
GL_SHADING_RATE_4X1_PIXELS_EXT=_C('GL_SHADING_RATE_4X1_PIXELS_EXT',0x96AB)
GL_SHADING_RATE_4X2_PIXELS_EXT=_C('GL_SHADING_RATE_4X2_PIXELS_EXT',0x96AC)
GL_SHADING_RATE_4X4_PIXELS_EXT=_C('GL_SHADING_RATE_4X4_PIXELS_EXT',0x96AE)
GL_SHADING_RATE_ATTACHMENT_EXT=_C('GL_SHADING_RATE_ATTACHMENT_EXT',0x96D1)
GL_SHADING_RATE_EXT=_C('GL_SHADING_RATE_EXT',0x96D0)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei)
def glFramebufferShadingRateEXT(target,attachment,texture,baseLayer,numLayers,texelWidth,texelHeight):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLuintArray)
def glGetFragmentShadingRatesEXT(samples,maxCount,count,shadingRates):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glShadingRateCombinerOpsEXT(combinerOp0,combinerOp1):pass
@_f
@_p.types(None,_cs.GLenum)
def glShadingRateEXT(rate):pass
