'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_conditional_render'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_conditional_render',error_checker=_errors._error_checker)
GL_QUERY_BY_REGION_NO_WAIT_NV=_C('GL_QUERY_BY_REGION_NO_WAIT_NV',0x8E16)
GL_QUERY_BY_REGION_WAIT_NV=_C('GL_QUERY_BY_REGION_WAIT_NV',0x8E15)
GL_QUERY_NO_WAIT_NV=_C('GL_QUERY_NO_WAIT_NV',0x8E14)
GL_QUERY_WAIT_NV=_C('GL_QUERY_WAIT_NV',0x8E13)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glBeginConditionalRenderNV(id,mode):pass
@_f
@_p.types(None,)
def glEndConditionalRenderNV():pass
