'''OpenGL extension SGIX.ir_instrument1

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.ir_instrument1 to provide a more 
Python-friendly API

Overview (from the spec)


The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/ir_instrument1.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.ir_instrument1 import *
from OpenGL.raw.GL.SGIX.ir_instrument1 import _EXTENSION_NAME

def glInitIrInstrument1SGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION